@@ -4,7 +4,9 @@ import errno
 import logging
 import os
 import requests
+import shutil
 import sys
+import tempfile
 import time
 import tzlocal
 from datetime import datetime
@@ -112,6 +114,18 @@ def get_owner(token):
     return result
 
 
+def atomic_write_file(fname, contents_str):
+    """Atomically write a string to a file by writing it to a temporary file, and then
+    renaming it to the final destination name. This solves a race condition where existence
+    of a file doesn't necessarily mean the contents are all correct yet."""
+    _ensure_intermediate_dirs(fname)
+    with tempfile.NamedTemporaryFile(mode="w", dir=os.path.dirname(fname), delete=False) as f:
+        log.debug("writing to tempfile @ %s", f.name)
+        f.write(contents_str)
+    log.debug("moving %s -> %s", f.name, fname)
+    shutil.move(f.name, fname)
+
+
 def _cli_guess(choice, choices):
     if choice in choices:
         return choice
